diff --git a/src/main.c b/src/main.c
index 279ecdf..cc92906 100644
--- a/src/main.c
+++ b/src/main.c
@@ -608,7 +608,7 @@ static void parse_command_line_options(gint *argc, gchar ***argv)
 	}
 	else
 	{
-		app->configdir = g_build_filename(g_get_user_config_dir(), "geany", NULL);
+		app->configdir = utils_get_user_config_dir();
 	}
 
 	if (generate_tags)
diff --git a/src/utils.c b/src/utils.c
index e4c5448..574ca8b 100644
--- a/src/utils.c
+++ b/src/utils.c
@@ -2078,3 +2078,13 @@ gchar *utils_parse_and_format_build_date(const gchar *input)
 
 	return g_strdup(input);
 }
+
+
+gchar *utils_get_user_config_dir(void)
+{
+#ifdef G_OS_WIN32
+	return win32_get_user_config_dir();
+#else
+	return g_build_filename(g_get_user_data_dir(), "geany", NULL);
+#endif
+}
diff --git a/src/utils.h b/src/utils.h
index c4df0bd..7e14099 100644
--- a/src/utils.h
+++ b/src/utils.h
@@ -289,6 +289,8 @@ GDate *utils_parse_date(const gchar *input);
 
 gchar *utils_parse_and_format_build_date(const gchar *input);
 
+gchar *utils_get_user_config_dir(void);
+
 G_END_DECLS
 
 #endif /* GEANY_UTILS_H */
diff --git a/src/win32.c b/src/win32.c
index eaf5afb..3fe44e6 100644
--- a/src/win32.c
+++ b/src/win32.c
@@ -1497,4 +1497,34 @@ gchar *win32_get_installation_dir(void)
 }
 
 
+gchar *win32_get_user_config_dir(void)
+{
+	wchar_t wdata_dir[MAX_PATH] = {0};
+
+	if (SHGetSpecialFolderPath(NULL, CSIDL_APPDATA, TRUE))
+	{
+		/* FIXME: should probably pre-flight the WideCharToMultiByte() call
+		 * to get the proper length since this UTF-8 encoded bytes which will
+		 * probably be more than when encoded as UTF-16/wchar */
+		gchar u8data_dir[MAX_PATH+1] = {0};
+
+		if (WideCharToMultiByte(CP_UTF8, 0, wdata_dir, -1, u8data_dir, MAX_PATH, NULL, NULL))
+		{
+			gchar *locale_data_dir;
+
+			locale_data_dir = g_win32_locale_filename_from_utf8(u8data_dir);
+
+			if (locale_data_dir)
+			{
+				gchar *full_path;
+				full_path = g_build_filename(locale_data_dir, "geany", NULL);
+				g_free(locale_data_dir);
+				return full_path;
+			}
+		}
+	}
+
+	return g_build_filename(g_get_user_config_dir(), "geany", NULL);
+}
+
 #endif
diff --git a/src/win32.h b/src/win32.h
index 72de162c..ad1af90 100644
--- a/src/win32.h
+++ b/src/win32.h
@@ -71,6 +71,8 @@ gchar *win32_get_installation_dir(void);
 
 gchar *win32_expand_environment_variables(const gchar *str);
 
+gchar *win32_get_user_config_dir(void);
+
 G_END_DECLS
 
 #endif /* G_OS_WIN32 */
